@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -71,6 +43,7 @@ import com.openexchange.client.onboarding.carddav.custom.CustomLoginSource;
 import com.openexchange.client.onboarding.net.HostAndPort;
 import com.openexchange.client.onboarding.net.NetUtility;
 import com.openexchange.client.onboarding.plist.OnboardingPlistProvider;
+import com.openexchange.client.onboarding.plist.PlistProviderNames;
 import com.openexchange.client.onboarding.plist.PlistResult;
 import com.openexchange.config.cascade.ComposedConfigProperty;
 import com.openexchange.config.cascade.ConfigView;
@@ -78,10 +51,12 @@ import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.groupware.userconfiguration.Permission;
+import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.java.Strings;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.plist.PListDict;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.serverconfig.ServerConfigService;
 import com.openexchange.session.Session;
 
 
@@ -225,26 +200,6 @@ public class CardDAVOnboardingProvider implements OnboardingPlistProvider {
 
     @Override
     public PListDict getPlist(PListDict optPrevPListDict, Scenario scenario, String hostName, int userId, int contextId) throws OXException {
-        // Get the PListDict to contribute to
-        PListDict pListDict;
-        if (null == optPrevPListDict) {
-            pListDict = new PListDict();
-            pListDict.setPayloadIdentifier("com.open-xchange." + scenario.getId());
-            pListDict.setPayloadType("Configuration");
-            pListDict.setPayloadUUID(OnboardingUtility.craftUUIDFrom(scenario.getId(), userId, contextId).toString());
-            pListDict.setPayloadVersion(1);
-            pListDict.setPayloadDisplayName(scenario.getDisplayName(userId, contextId));
-        } else {
-            pListDict = optPrevPListDict;
-        }
-
-        // Generate payload content dictionary
-        PListDict payloadContent = new PListDict();
-        payloadContent.setPayloadType("com.apple.carddav.account");
-        payloadContent.setPayloadUUID(OnboardingUtility.craftUUIDFrom(identifier, userId, contextId).toString());
-        payloadContent.setPayloadIdentifier("com.open-xchange.carddav");
-        payloadContent.setPayloadVersion(1);
-        payloadContent.addStringValue("PayloadOrganization", "Open-Xchange");
         String login;
         {
             Boolean customSource = OnboardingUtility.getBoolFromProperty("com.openexchange.client.onboarding.carddav.login.customsource", Boolean.FALSE, userId, contextId);
@@ -260,6 +215,30 @@ public class CardDAVOnboardingProvider implements OnboardingPlistProvider {
                 login = OnboardingUtility.getUserLogin(userId, contextId);
             }
         }
+
+        String defaultName = StringHelper.valueOf(OnboardingUtility.getLocaleFor(userId, contextId)).getString(PlistProviderNames.PROFILE_NAME_CARDDAV);
+        String scenarioDisplayName = getPListPayloadName(defaultName, services.getOptionalService(ServerConfigService.class), hostName, userId, contextId);
+
+        // Get the PListDict to contribute to
+        PListDict pListDict;
+        if (null == optPrevPListDict) {
+            pListDict = new PListDict();
+            pListDict.setPayloadIdentifier(OnboardingUtility.reverseDomainNameString(hostName) + "." + scenario.getId() + "." + OnboardingUtility.dropWhitespacesAndLowerCaseFor(login));
+            pListDict.setPayloadType("Configuration");
+            pListDict.setPayloadUUID(OnboardingUtility.craftScenarioUUIDFrom(scenario.getId(), userId, contextId).toString());
+            pListDict.setPayloadVersion(1);
+            pListDict.setPayloadDisplayName(scenarioDisplayName);
+        } else {
+            pListDict = optPrevPListDict;
+        }
+
+        // Generate payload content dictionary
+        PListDict payloadContent = new PListDict();
+        payloadContent.setPayloadType("com.apple.carddav.account");
+        payloadContent.setPayloadUUID(OnboardingUtility.craftProviderUUIDFrom(identifier, userId, contextId).toString());
+        payloadContent.setPayloadIdentifier(OnboardingUtility.reverseDomainNameString(hostName) + ".carddav");
+        payloadContent.setPayloadVersion(1);
+        payloadContent.addStringValue("PayloadOrganization", "Open-Xchange");
         payloadContent.addStringValue("CardDAVUsername", login);
 
         {
