@@ -1,72 +1,52 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.client.onboarding.json.actions;
 
+import java.io.IOException;
 import java.util.Collections;
 import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.Optional;
 import org.json.JSONException;
+import com.openexchange.ajax.container.ThresholdFileHolder;
+import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.client.onboarding.BuiltInProvider;
+import com.openexchange.client.onboarding.OnboardingExceptionCodes;
 import com.openexchange.client.onboarding.OnboardingUtility;
 import com.openexchange.client.onboarding.plist.OnboardingPlistProvider;
+import com.openexchange.client.onboarding.plist.PListSigner;
 import com.openexchange.client.onboarding.plist.PlistScenario;
 import com.openexchange.client.onboarding.plist.PlistScenarioType;
 import com.openexchange.client.onboarding.plist.PlistUtility;
 import com.openexchange.client.onboarding.service.OnboardingService;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.groupware.userconfiguration.Permission;
+import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
 import com.openexchange.plist.PListDict;
+import com.openexchange.plist.PListWriter;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
@@ -162,14 +142,59 @@ public class DownloadAction extends AbstractOnboardingAction {
             }
         }
 
-        // Generate synthetic scenario
-        PListDict dict = null;
-        for (Map.Entry<String, OnboardingPlistProvider> providerEntry : onboardingProviders.entrySet()) {
-            OnboardingPlistProvider provider = providerEntry.getValue();
-            PlistScenario scenario = PlistScenario.newInstance(providerEntry.getKey(), Collections.singletonList(provider));
-            dict = provider.getPlist(dict, scenario, requestData.getHostData().getHost(), session.getUserId(), session.getContextId());
+        // Generate synthetic scenario and sign result
+        PListDict dict = generatePListDict(requestData, session, onboardingProviders);
+        if (dict == null) {
+            return new AJAXRequestResult();
+        }
+        
+        PListSigner signer = services.getOptionalService(PListSigner.class);
+        if (null != signer) {
+            boolean error = true;
+            ThresholdFileHolder fileHolder = null;
+            try {
+                fileHolder = new ThresholdFileHolder();
+                fileHolder.setDisposition("attachment");
+                fileHolder.setName("profile.mobileconfig");
+                fileHolder.setContentType("application/x-apple-aspen-config");
+                fileHolder.setDelivery("download");
+                new PListWriter().write(dict, fileHolder.asOutputStream());
+                IFileHolder signed = signer.signPList(fileHolder, session);
+                fileHolder = new ThresholdFileHolder(signed);
+                signed.close();
+                error = false;
+                return new AJAXRequestResult(fileHolder, "signed_plist_download");
+            } catch (IOException e) {
+                throw OnboardingExceptionCodes.IO_ERROR.create(e, e.getMessage());
+            } finally {
+                if (error) {
+                    Streams.close(fileHolder);
+                }
+            }
         }
         return new AJAXRequestResult(dict, "plist_download");
     }
 
+    /**
+     * Generate a possible synthetic scenario
+     *
+     * @param requestData The {@link AJAXRequestData}
+     * @param session The session
+     * @param onboardingProviders the onboarding providers
+     * @return The possible {@link PListDict} with the synthetic scenario
+     * @throws OXException
+     */
+    private PListDict generatePListDict(AJAXRequestData requestData, ServerSession session, Map<String, OnboardingPlistProvider> onboardingProviders) throws OXException {
+        HostData hostData = requestData.getHostData();
+        if (hostData == null) {
+            return null;
+        }
+        PListDict dict = null;
+        for (Map.Entry<String, OnboardingPlistProvider> providerEntry : onboardingProviders.entrySet()) {
+            OnboardingPlistProvider provider = providerEntry.getValue();
+            PlistScenario scenario = PlistScenario.newInstance(providerEntry.getKey(), Collections.singletonList(provider));
+            dict = provider.getPlist(dict, scenario, hostData.getHost(), session.getUserId(), session.getContextId());
+        }
+        return dict;
+    }
 }
