@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -70,10 +42,12 @@ import com.openexchange.client.onboarding.ResultReply;
 import com.openexchange.client.onboarding.Scenario;
 import com.openexchange.client.onboarding.mail.custom.CustomLoginSource;
 import com.openexchange.client.onboarding.plist.OnboardingPlistProvider;
+import com.openexchange.client.onboarding.plist.PlistProviderNames;
 import com.openexchange.client.onboarding.plist.PlistResult;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.userconfiguration.Permission;
+import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.java.Strings;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.api.MailConfig;
@@ -87,6 +61,7 @@ import com.openexchange.osgi.ServiceListing;
 import com.openexchange.plist.PListDict;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.serverconfig.ServerConfigService;
 import com.openexchange.session.Session;
 import com.openexchange.session.Sessions;
 import com.openexchange.session.UserAndContext;
@@ -201,7 +176,7 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
             case LINK:
                 throw OnboardingExceptionCodes.UNSUPPORTED_TYPE.create(identifier, scenario.getType().getId());
             case MANUAL:
-                return doExecuteManual(request, previousResult, session);
+                return doExecuteManual(previousResult, session);
             case PLIST:
                 return doExecutePlist(request, previousResult, session);
             default:
@@ -262,6 +237,15 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
                 configBuilder.withSecure(imapSecure.booleanValue());
             }
 
+            // STARTTLS required
+            {
+                Boolean imapRequireTls = OnboardingUtility.getBoolFromProperty("com.openexchange.client.onboarding.mail.imap.requireTls", null, userId, contextId);
+                if (null == imapRequireTls) {
+                    imapRequireTls = Boolean.valueOf(mailSettings.isRequireTls());
+                }
+                configBuilder.withRequireTls(imapRequireTls.booleanValue());
+            }
+
             // Login
             {
                 String imapLogin;
@@ -337,6 +321,15 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
                 configBuilder.withSecure(smtpSecure.booleanValue());
             }
 
+            // STARTTLS required
+            {
+                Boolean smtpRequireTls = OnboardingUtility.getBoolFromProperty("com.openexchange.client.onboarding.mail.smtp.requireTls", null, userId, contextId);
+                if (null == smtpRequireTls) {
+                    smtpRequireTls = Boolean.valueOf(transportSettings.isRequireTls());
+                }
+                configBuilder.withRequireTls(smtpRequireTls.booleanValue());
+            }
+
             // Password
             {
                 String smtpPassword = transportSettings.getPassword();
@@ -426,8 +419,8 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
         return plistResult(request, previousResult, session);
     }
 
-    private Result doExecuteManual(OnboardingRequest request, Result previousResult, Session session) throws OXException {
-        return displayResult(request, previousResult, session);
+    private Result doExecuteManual(Result previousResult, Session session) throws OXException {
+        return displayResult(previousResult, session);
     }
 
     // --------------------------------------------------------------------------------------------------------------------------
@@ -441,7 +434,7 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
     private final static String SMTP_PORT_FIELD = "smtpPort";
     private final static String SMTP_SECURE_FIELD = "smtpSecure";
 
-    private Result displayResult(OnboardingRequest request, Result previousResult, Session session) throws OXException {
+    private Result displayResult(Result previousResult, Session session) throws OXException {
         Configurations configurations;
         {
             MailConfig mailConfig = services.getService(MailService.class).getMailConfig(session, MailAccount.DEFAULT_ID);
@@ -506,15 +499,18 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
     public PListDict getPlist(PListDict optPrevPListDict, Scenario scenario, String hostName, int userId, int contextId) throws OXException {
         Configurations configurations = getEffectiveConfigurations(userId, contextId);
 
+        String defaultName = StringHelper.valueOf(OnboardingUtility.getLocaleFor(userId, contextId)).getString(PlistProviderNames.PROFILE_NAME_MAIL);
+        String scenarioDisplayName = getPListPayloadName(defaultName, services.getOptionalService(ServerConfigService.class), hostName, userId, contextId);
+
         // Get the PListDict to contribute to
         PListDict pListDict;
         if (null == optPrevPListDict) {
             pListDict = new PListDict();
-            pListDict.setPayloadIdentifier("com.open-xchange." + scenario.getId());
+            pListDict.setPayloadIdentifier(OnboardingUtility.reverseDomainNameString(hostName) + "." + scenario.getId() + "." + OnboardingUtility.dropWhitespacesAndLowerCaseFor(configurations.imapConfig.login));
             pListDict.setPayloadType("Configuration");
-            pListDict.setPayloadUUID(OnboardingUtility.craftUUIDFrom(scenario.getId(), userId, contextId).toString());
+            pListDict.setPayloadUUID(OnboardingUtility.craftScenarioUUIDFrom(scenario.getId(), userId, contextId).toString());
             pListDict.setPayloadVersion(1);
-            pListDict.setPayloadDisplayName(scenario.getDisplayName(userId, contextId));
+            pListDict.setPayloadDisplayName(scenarioDisplayName);
         } else {
             pListDict = optPrevPListDict;
         }
@@ -522,8 +518,8 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
         // Generate content
         PListDict payloadContent = new PListDict();
         payloadContent.setPayloadType("com.apple.mail.managed");
-        payloadContent.setPayloadUUID(OnboardingUtility.craftUUIDFrom(identifier, userId, contextId).toString());
-        payloadContent.setPayloadIdentifier("com.open-xchange.mail");
+        payloadContent.setPayloadUUID(OnboardingUtility.craftProviderUUIDFrom(identifier, userId, contextId).toString());
+        payloadContent.setPayloadIdentifier(OnboardingUtility.reverseDomainNameString(hostName) + ".mail");
         payloadContent.setPayloadVersion(1);
 
         // A user-visible description of the email account, shown in the Mail and Settings applications.
@@ -550,7 +546,7 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
         payloadContent.addIntegerValue("IncomingMailServerPortNumber", configurations.imapConfig.port);
 
         // Designates whether the incoming mail server uses SSL for authentication. Default false.
-        payloadContent.addBooleanValue("IncomingMailServerUseSSL", configurations.imapConfig.secure);
+        payloadContent.addBooleanValue("IncomingMailServerUseSSL", configurations.imapConfig.secure || configurations.imapConfig.requireTls);
 
         // Designates the user name for the email account, usually the same as the email address up to the @ character.
         // If not present in the payload, and the account is set up to require authentication for incoming email, the device will prompt for this string during profile installation.
@@ -569,7 +565,7 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
         payloadContent.addIntegerValue("OutgoingMailServerPortNumber", configurations.smtpConfig.port);
 
         // Designates whether the outgoing mail server uses SSL for authentication. Default false.
-        payloadContent.addBooleanValue("OutgoingMailServerUseSSL", configurations.smtpConfig.secure);
+        payloadContent.addBooleanValue("OutgoingMailServerUseSSL", configurations.smtpConfig.secure || configurations.smtpConfig.requireTls);
 
         // Designates the user name for the email account, usually the same as the email address up to the @ character.
         // If not present in the payload, and the account is set up to require authentication for outgoing email, the device prompts for this string during profile installation.
