@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -54,7 +26,9 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
@@ -134,32 +108,111 @@ public class OnboardingUtility {
     }
 
     /**
-     * Crafts a UUID for specified scenario for given user.
+     * Crafts a UUID for specified arguments for given user.
      *
      * @param identifier The identifier to craft from
+     * @param type The optional type identifier; e.g. <code>"scenario"</code> or <code>"provider"</code>
      * @param session The session providing user data
      * @return The crafted UUID
      */
-    public static UUID craftUUIDFrom(String identifier, Session session) {
-        return craftUUIDFrom(identifier, session.getUserId(), session.getContextId());
+    public static UUID craftUUIDFrom(String identifier, String type, Session session) {
+        return craftUUIDFrom(identifier, type, session.getUserId(), session.getContextId());
+    }
+
+    /**
+     * Crafts a UUID for specified arguments for given user.
+     *
+     * @param identifier The identifier to craft from
+     * @param type The optional type identifier to consider when crafting UUID; e.g. <code>"scenario"</code> or <code>"provider"</code>
+     * @param userId The user id
+     * @param contextId The context id
+     * @return The crafted UUID
+     */
+    public static UUID craftUUIDFrom(String identifier, String type, int userId, int contextId) {
+        return new UUID(longFor(identifier.hashCode(), (Strings.isEmpty(type) ? "open-xchange" : type).hashCode()), longFor(userId, contextId));
     }
 
     /**
      * Crafts a UUID for specified scenario for given user.
      *
      * @param identifier The identifier to craft from
+     * @param type The optional type identifier to consider when crafting UUID; e.g. <code>"scenario"</code> or <code>"provider"</code>
      * @param userId The user id
      * @param contextId The context id
      * @return The crafted UUID
      */
-    public static UUID craftUUIDFrom(String identifier, int userId, int contextId) {
-        return new UUID(longFor(identifier.hashCode(), "open-xchange".hashCode()), longFor(userId, contextId));
+    public static UUID craftScenarioUUIDFrom(String identifier, int userId, int contextId) {
+        return craftUUIDFrom(identifier, "scenario", userId, contextId);
+    }
+
+    /**
+     * Crafts a UUID for specified provider for given user.
+     *
+     * @param identifier The identifier to craft from
+     * @param type The optional type identifier to consider when crafting UUID; e.g. <code>"scenario"</code> or <code>"provider"</code>
+     * @param userId The user id
+     * @param contextId The context id
+     * @return The crafted UUID
+     */
+    public static UUID craftProviderUUIDFrom(String identifier, int userId, int contextId) {
+        return craftUUIDFrom(identifier, "provider", userId, contextId);
     }
 
     private static long longFor(int x, int y) {
         return ((((long) x) << 32) | (y & 0xffffffffL));
     }
 
+    /**
+     * Reverses a domain name. E.g. "openexchange.com" -> "com.openexchange"
+     *
+     * @param domain The domain
+     * @return The reversed domain
+     */
+    public static String reverseDomainNameString(String domain) {
+        List<String> components = Arrays.asList(Strings.splitByDots(domain));
+        Collections.reverse(components);
+        return String.join(".", components.toArray(new String[0]));
+    }
+
+    /**
+     * Drops white-space characters from given string (if any) and returns its lower-case representation.
+     *
+     * @param str The string to examine
+     * @return The lower-case string without white-spaces
+     */
+    public static String dropWhitespacesAndLowerCaseFor(String str) {
+        if (str == null) {
+            return null;
+        }
+
+        int length = str.length();
+        if (length <= 0) {
+            return str;
+        }
+
+        StringBuilder sb = null;
+        for (int i = 0; i < length; i++) {
+            char ch = str.charAt(i);
+            if (Strings.isWhitespace(ch)) {
+                if (sb == null) {
+                    sb = new StringBuilder(length);
+                    if (i > 0) {
+                        sb.append(str, 0, i);
+                    }
+                }
+            } else {
+                if (sb != null) {
+                    sb.append(ch);
+                }
+            }
+        }
+
+        if (sb == null) {
+            return Strings.asciiLowerCase(str);
+        }
+        return sb.length() > 0 ? Strings.asciiLowerCase(sb.toString()) : "";
+    }
+
     /**
      * Parses the specified composite identifier; e.g. <code>"apple.iphone/davsync"</code>.
      *
